﻿
using FabAccessAPI;
using FabAccessAPI.Exceptions;
using NUnit.Framework;
using System;
using System.Collections.Generic;

namespace FabAccessAPI_Test
{
    public class API_Test
    {
        [TestCase("Admin1")]
        public void ConnectDisconnect(string username)
        {
            API api = new API();

            ConnectionData connectionData = new ConnectionData()
            {
                Host = new UriBuilder(TestEnv.SCHEMA, TestEnv.TESTSERVER, TestEnv.TESTSERVER_PORT).Uri,
                Mechanism = Mechanism.PLAIN,
                Username = username,
                Properties = new Dictionary<string, object>()
                {
                    { "Username", username }
                },
                SecretProperties = new Dictionary<string, object>()
                {
                    { "Password", TestEnv.PASSWORD }
                }
            };

            api.Connect(connectionData);
            api.Disconnect();
        }

        [Test]
        public void Connect_HostUnreachable()
        {
            API api = new API();

            ConnectionData connectionData = new ConnectionData()
            {
                Host = new UriBuilder(TestEnv.SCHEMA, "NotReachable." + TestEnv.TESTSERVER, TestEnv.TESTSERVER_PORT).Uri,
                Mechanism = Mechanism.PLAIN,
                Username = "UnknownUser",
                Properties = new Dictionary<string, object>()
                {
                    { "Username", "UnknownUser" }
                },
                SecretProperties = new Dictionary<string, object>()
                {
                    { "Password", TestEnv.PASSWORD }
                }
            };

            Assert.Throws<ConnectingFailedException>(() =>
            {
                api.Connect(connectionData);
            });
        }

        [Test]
        public void Connect_InvalidCredentials()
        {
            API api = new API();

            ConnectionData connectionData = new ConnectionData()
            {
                Host = new UriBuilder(TestEnv.SCHEMA, TestEnv.TESTSERVER, TestEnv.TESTSERVER_PORT).Uri,
                Mechanism = Mechanism.PLAIN,
                Username = "UnknownUser",
                Properties = new Dictionary<string, object>()
                {
                    { "Username", "UnknownUser" }
                },
                SecretProperties = new Dictionary<string, object>()
                {
                    { "Password", TestEnv.PASSWORD }
                }
            };

            Assert.Throws<InvalidCredentialsException>(() =>
            {
                api.Connect(connectionData);
            });
        }
    }
}
